==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/SkuResourcePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.SkuResourcePropertiesArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.ProvisioningState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property provisioningState The provisioned state of the resource.
 * @property skuSettings
 */
public data class SkuResourcePropertiesArgs(
    public val provisioningState: Output<Either<String, ProvisioningState>>? = null,
    public val skuSettings: Output<List<SkuSettingArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.SkuResourcePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.SkuResourcePropertiesArgs =
        com.pulumi.azurenative.providerhub.inputs.SkuResourcePropertiesArgs.builder()
            .provisioningState(
                provisioningState?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .skuSettings(
                skuSettings.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SkuResourcePropertiesArgs].
 */
@PulumiTagMarker
public class SkuResourcePropertiesArgsBuilder internal constructor() {
    private var provisioningState: Output<Either<String, ProvisioningState>>? = null

    private var skuSettings: Output<List<SkuSettingArgs>>? = null

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("pjnboljpwcxyrdjm")
    public suspend fun provisioningState(`value`: Output<Either<String, ProvisioningState>>) {
        this.provisioningState = value
    }

    /**
     * @param value
     */
    @JvmName("fsdgwtwvjdddiugx")
    public suspend fun skuSettings(`value`: Output<List<SkuSettingArgs>>) {
        this.skuSettings = value
    }

    @JvmName("fkobdvrwvbfxpoil")
    public suspend fun skuSettings(vararg values: Output<SkuSettingArgs>) {
        this.skuSettings = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("xsemnfkwrwggwxsi")
    public suspend fun skuSettings(values: List<Output<SkuSettingArgs>>) {
        this.skuSettings = Output.all(values)
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("cssnxfngbdacehus")
    public suspend fun provisioningState(`value`: Either<String, ProvisioningState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("nehjbkxrkgosedhb")
    public fun provisioningState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("ijvvqqijnsbwplbi")
    public fun provisioningState(`value`: ProvisioningState) {
        val toBeMapped = Either.ofRight<String, ProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value
     */
    @JvmName("umahpqnuugtelapc")
    public suspend fun skuSettings(`value`: List<SkuSettingArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.skuSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("jhewyaugffkjadnp")
    public suspend fun skuSettings(argument: List<suspend SkuSettingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SkuSettingArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.skuSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("pijenyfjovmadrbr")
    public suspend fun skuSettings(vararg argument: suspend SkuSettingArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { SkuSettingArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.skuSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ohjpyttfgjuvluaq")
    public suspend fun skuSettings(argument: suspend SkuSettingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SkuSettingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.skuSettings = mapped
    }

    /**
     * @param values
     */
    @JvmName("xppjmjkgxjcxgstp")
    public suspend fun skuSettings(vararg values: SkuSettingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.skuSettings = mapped
    }

    internal fun build(): SkuResourcePropertiesArgs = SkuResourcePropertiesArgs(
        provisioningState = provisioningState,
        skuSettings = skuSettings ?: throw PulumiNullFieldException("skuSettings"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/SkuResourcePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.SkuResourcePropertiesArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.ProvisioningState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property provisioningState The provisioned state of the resource.
 * @property skuSettings
 */
public data class SkuResourcePropertiesArgs(
    public val provisioningState: Output<Either<String, ProvisioningState>>? = null,
    public val skuSettings: Output<List<SkuSettingArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.SkuResourcePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.SkuResourcePropertiesArgs =
        com.pulumi.azurenative.providerhub.inputs.SkuResourcePropertiesArgs.builder()
            .provisioningState(
                provisioningState?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .skuSettings(
                skuSettings.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SkuResourcePropertiesArgs].
 */
@PulumiTagMarker
public class SkuResourcePropertiesArgsBuilder internal constructor() {
    private var provisioningState: Output<Either<String, ProvisioningState>>? = null

    private var skuSettings: Output<List<SkuSettingArgs>>? = null

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("cpqgnitsgkerppsg")
    public suspend fun provisioningState(`value`: Output<Either<String, ProvisioningState>>) {
        this.provisioningState = value
    }

    /**
     * @param value
     */
    @JvmName("pxwbomworhrgapal")
    public suspend fun skuSettings(`value`: Output<List<SkuSettingArgs>>) {
        this.skuSettings = value
    }

    @JvmName("upecijuurnbxpyvr")
    public suspend fun skuSettings(vararg values: Output<SkuSettingArgs>) {
        this.skuSettings = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("vagjlbqwgnudmydd")
    public suspend fun skuSettings(values: List<Output<SkuSettingArgs>>) {
        this.skuSettings = Output.all(values)
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("jtwhumuyqddmvuhl")
    public suspend fun provisioningState(`value`: Either<String, ProvisioningState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("jlrbibxandtbhoua")
    public fun provisioningState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The provisioned state of the resource.
     */
    @JvmName("aanmkrykspqjpktl")
    public fun provisioningState(`value`: ProvisioningState) {
        val toBeMapped = Either.ofRight<String, ProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value
     */
    @JvmName("qgvxtidlmjxuhhsn")
    public suspend fun skuSettings(`value`: List<SkuSettingArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.skuSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ekfgocqpctoldblt")
    public suspend fun skuSettings(argument: List<suspend SkuSettingArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SkuSettingArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.skuSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kepxuvhvbuqohstj")
    public suspend fun skuSettings(vararg argument: suspend SkuSettingArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { SkuSettingArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.skuSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ibesnhtulhpgubyw")
    public suspend fun skuSettings(argument: suspend SkuSettingArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SkuSettingArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.skuSettings = mapped
    }

    /**
     * @param values
     */
    @JvmName("qccmwkqbishlojsp")
    public suspend fun skuSettings(vararg values: SkuSettingArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.skuSettings = mapped
    }

    internal fun build(): SkuResourcePropertiesArgs = SkuResourcePropertiesArgs(
        provisioningState = provisioningState,
        skuSettings = skuSettings ?: throw PulumiNullFieldException("skuSettings"),
    )
}
